---
date: "2022-05-03"
title: "0.22 Upgrade Guide"
description: "An upgrade guide that addresses breaking changes in 0.22.0"
authors: ["spencergilbert", "jszwedko"]
pr_numbers: [12124]
release: "0.22.0"
hide_on_release_notes: false
badges:
  type: breaking change
---

Vector's 0.22.0 release includes **breaking changes**:

1. [`gcp_stackdriver_metrics` configuration change](#stackdriver-metrics)
2. [VRL now supports template strings](#vrl-template-strings)
3. [`encode_key_value` and `encode_logfmt` quote wrapping behavior change](#encode-key-value-quote-wrapping)

We cover them below to help you upgrade quickly:

## Upgrade guide

### Breaking changes

#### `gcp_stackdriver_metrics` configuration change {#stackdriver-metrics}

The `gcp_stackdriver_metrics` sink now matches the `gcp_stackdriver_logs`
configuration, and doesn't require an additional `labels` section to add
labels to submitted metrics.

### TOML transform example

Old configuration

```toml
[sinks.my_sink_id]
type = "gcp_stackdriver_metrics"
inputs = [ "my-source-or-transform-id" ]
credentials_path = "/path/to/credentials.json"
project_id = "vector-123456"

  [sinks.my_sink_id.resource]
  type = "global"

    [sinks.my_sink_id.resource.labels]
    projectId = "vector-123456"
    instanceId = "Twilight"
    zone = "us-central1-a"
```

New configuration

```toml
[sinks.my_sink_id]
type = "gcp_stackdriver_metrics"
inputs = [ "my-source-or-transform-id" ]
credentials_path = "/path/to/credentials.json"
project_id = "vector-123456"

  [sinks.my_sink_id.resource]
  type = "global"
  projectId = "vector-123456"
  instanceId = "Twilight"
  zone = "us-central1-a"
```

For more information on the new syntax, you can review the documentation [here](https://vector.dev/docs/reference/configuration/sinks/gcp_stackdriver_metrics/)


#### VRL now supports template strings {#vrl-template-strings}

VRL strings can now be templated. It is now possible to insert the values of
variables by inserting a placeholder with an embedded variable name into the
string using `{{..}}`. For example in the following code:

```coffee
beverage = "coffee"
preference = "I love to drink {{ beverage }}!"

assert!(preference == "I love to drink coffee!")
```

It should be noted that currently the placeholder must contain a simple
variable name and that variable must resolve to a string.

This will not work:

```coffee
stars = 42
sky = "There are {{ stars }} in the sky."
```

Instead, the variable must be converted to a string first:

```coffee
stars = to_string(42)
sky = "There are {{ stars }} in the sky."
```

Also paths are currently not supported, so this will not work:

```coffee
message = "The message is {{ .message }}."
```

Assign the field to a variable first:

```coffee
message = .message
message = "The message is {{ message }}."
```

If you wish to insert `{{` into the string, you can escape using `\{{` and `\}}`.
You also still have the option to use raw strings (`s'...'`):

```coffee
assert!("\{{ right here \}}" == s'{{ right here }}')
```

#### `encode_key_value` and `encode_logfmt` quote wrapping behavior change {#encode-key-value-quote-wrapping}

Values and keys containing whitespace and/or double quotes are now wrapped in
double quotes with the original quotes escaped. This change brings
`encode_logfmt` inline with the [defined spec](https://pkg.go.dev/github.com/kr/logfmt#pkg-overview)
used by other libraries.

Previously, only keys and values containing whitespace were wrapped in quotes.

If using `encode_logfmt`, the previous behavior would result in messages similar to:

```text
lvl=info msg={"some":"val"}
```

With this change, the message would be encoded as:

```text
lvl=info msg="{\"some\":\"val\"}"
```
